@@ -204,7 +204,7 @@ void new_vector(GtkMenuItem *w, gpointer user_data);
 void new_unit(GtkMenuItem *w, gpointer user_data);
 void add_as_variable();
 
-void fetch_exchange_rates(int timeout);
+void fetch_exchange_rates(int timeout, int n = -1);
 
 bool edit_argument(Argument *arg = NULL);
 
@@ -256,7 +256,6 @@ void on_preferences_checkbutton_alternative_base_prefixes_toggled(GtkToggleButto
 void on_preferences_checkbutton_spell_out_logical_operators_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_unicode_signs_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_display_expression_status_toggled(GtkToggleButton *w, gpointer user_data);
-void on_preferences_checkbutton_enable_completion_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_fetch_exchange_rates_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_save_defs_toggled(GtkToggleButton *w, gpointer user_data);
 void on_preferences_checkbutton_save_mode_toggled(GtkToggleButton *w, gpointer user_data);
